<p align="center">
    <br>
    <img src="./assets/phoenixcat_logo_transparent.png" alt="phoenixcat_logo_transparent" width="550" />
    <br>
<p>
Phoenixcat is an enhanced infrastructure library for PyTorch.

## Installation
Install the library from PyPI:
```bash
pip install phoenixcat
```
or install the latest version from GitHub:
```
pip install git+https://github.com/Chrisqcwx/phoenixcat.git
```


## License

This project is licensed under the Apache-2.0 License. See the [LICENSE](./LICENSE) file for details.


## Acknowledgements

This project includes code from the [diffusers](https://github.com/huggingface/diffusers) which is licensed under the Apache License, Version 2.0.

## Citation

```bibtex
@software{yu2024phoenixcat,
    title        = {Phoenixcat: an enhanced infrastructure library for PyTorch.},
    author       = {Yu, Hongyao and Yu, Sijin},
    year         = 2024,
    journal      = {GitHub repository},
    publisher    = {GitHub},
    howpublished = {\url{https://github.com/Chrisqcwx/phoenixcat}}
}
```
